@@ -18,13 +18,13 @@ def strToDynamicType(var):
     # int() doesn't declare 'raises' in doc type so catch everything
     try:
         return int(var)
-    except:
+    except (ValueError, TypeError):
         pass
 
     # float() doesn't declare 'raises' in doc type so catch everything
     try:
         return float(var)
-    except:
+    except (ValueError, TypeError):
         pass
 
     return var
@@ -38,9 +38,11 @@ def _typeChecker_checkObject(obj, types, literalObjects):
     for i, typeTuple in enumerate(types):
         # Returned ValueError if obj was pandas.DataFrame, so there are probably more objects that can raise any error
         # So catch every exception, it's a pretty simple statement so not too big of a problem
-        try:
-            objInLiteralObjects = obj in literalObjects
-        except:
+        for literalObj in literalObjects:
+            if obj is literalObj:
+                objInLiteralObjects = True
+                break
+        else:
             objInLiteralObjects = False
 
         if objInLiteralObjects:
@@ -99,8 +101,9 @@ def _typeChecker_prepareTypesList(types, literalObjects):
 
 def typeChecker(obj, *types, error=True):
     """
-    Check types of an obj. Intended for iterables with somewhat consistent structure in every layer.
+    Check type(s) of an object.
     The first type correlates to the first layer of obj and so on.
+    Each type can be a (tuple that holds) type, string or literal object such as `None`.
 
     :param obj: Generic obj, iterable or not
     :param types: lists or tuples if obj at that level can be multiple types, single type if only one
@@ -123,12 +126,13 @@ def typeChecker(obj, *types, error=True):
     else:
         return True
 
-def getBaseClasses(obj, includeSelf=False):
+def getBaseClasses(obj, includeSelf=False, includeObject=True):
     """
     Get all base classes from an object's class.
 
     :param any obj: Generic obj or class
     :param includeSelf: Whether to include own class or not
+    :param includeObject: Whether to include object class or not (Every object has object as base)
     :return: List of classes
     :rtype: list[type]
     """
@@ -139,11 +143,16 @@ def getBaseClasses(obj, includeSelf=False):
 
     classes = list(cls.__bases__)
     for base in classes:
-        classes.extend(getBaseClasses(base))
+        for baseClassBase in getBaseClasses(base):
+            if baseClassBase not in classes:
+                classes.append(baseClassBase)
 
     if includeSelf:
         classes.insert(0, cls)
 
+    if not includeObject:
+        classes.remove(object)
+
     return classes
 
 def getBaseClassNames(obj, includeSelf=False):
@@ -157,4 +166,15 @@ def getBaseClassNames(obj, includeSelf=False):
     """
     return [cls.__name__.lower() for cls in getBaseClasses(obj, includeSelf)]
 
+def hasMethod(obj, method):
+    """
+    Return whether an object has a specific callabale attribute.
+
+    :param object obj: Any object
+    :param str method: String of method to check
+    """
+    attr = getattr(obj, method, False)
+    return attr and callable(attr)
+
+
 from generallibrary.iterables import depth, iterFirstValue, isIterable
